import os
import napkin


def test_png_generation(tmpdir):
    fname = os.path.join(str(tmpdir), 'sd')

    @napkin.seq_diagram(fname)
    def f(c):
        foo = c.object('foo')
        bar = c.object('bar')
        with foo:
            bar.func()

    napkin.generate(output_format='plantuml_png')
    assert os.stat(fname + '.puml')
    assert os.stat(fname + '.png')



import setuptools
import re

with open("README.md", "rt") as f:
    long_description = f.read()

with open("napkin/__init__.py", "rt") as f:
    version = re.search(r'__version__ = \'(.*?)\'', f.read()).group(1)

setuptools.setup(
    name="napkin",
    version=version,
    author="Hans Jang",
    author_email="hsjang8848@gmail.com",
    description="Python DSL for writing PlantUML sequence diagram",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/pinetr2e/napkin",
    packages=setuptools.find_packages(),
    setup_requires=["pytest-runner", 'plantuml'],
    tests_require=["pytest"],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        'Intended Audience :: Developers',
        'Environment :: Console',
        'Topic :: Software Development',
    ],
    entry_points={
        'console_scripts': [
            'napkin = napkin.cli:main',
        ],
    },
)



"""
Generate PlantUML script and PNG file
"""
import os
import plantuml
from . import gen_plantuml


def generate(diagram_name, output_dir, sd_context):
    generated_files = gen_plantuml.generate(diagram_name,
                                            output_dir, sd_context)
    puml_path = generated_files[0]
    png_path = os.path.join(output_dir, diagram_name + '.png')
    if plantuml.PlantUML().processes_file(puml_path, png_path):
        generated_files.append(png_path)
    return generated_files
